package com.aliyun.sample;

import java.util.List;

import com.aliyun.resourcesharing20200110.models.AcceptResourceShareInvitationRequest;
import com.aliyun.resourcesharing20200110.models.AcceptResourceShareInvitationResponse;
import com.aliyun.resourcesharing20200110.models.ListResourceShareInvitationsResponse;
import com.aliyun.resourcesharing20200110.models.ListResourceShareInvitationsResponseBody.ListResourceShareInvitationsResponseBodyResourceShareInvitations;
import com.aliyun.resourcesharing20200110.models.RejectResourceShareInvitationRequest;
import com.aliyun.resourcesharing20200110.models.RejectResourceShareInvitationResponse;
import com.aliyun.tea.TeaException;

/**
 * 本用例演示了资源使用者如何接受其他用户共享的资源
 * 资源共享管理接受共享邀请API参考文档：https://help.aliyun.com/document_detail/2330857.html
 * 开发者门户：https://api.aliyun.com/api/ResourceSharing/2020-01-10/ListResourceShareInvitations
 * 用例内容仅供参考，请根据实际情况修改
 **/
public class ReceiveResourceShare {

    /**
     * 使用AK&SK初始化账号Client
     *
     * @param accessKeyId
     * @param accessKeySecret
     * @return Client
     * @throws Exception
     */
    public static com.aliyun.resourcesharing20200110.Client createClient(String accessKeyId, String accessKeySecret)
        throws Exception {
        com.aliyun.teaopenapi.models.Config config = new com.aliyun.teaopenapi.models.Config()
            // 必填，您的 AccessKey ID
            .setAccessKeyId(accessKeyId)
            // 必填，您的 AccessKey Secret
            .setAccessKeySecret(accessKeySecret);
        // Endpoint 请参考 https://api.aliyun.com/product/ResourceSharing
        config.endpoint = "resourcesharing.cn-shenzhen.aliyuncs.com";
        return new com.aliyun.resourcesharing20200110.Client(config);
    }

    public static void main(String[] args_) throws Exception {
        // 请确保代码运行环境设置了环境变量 ALIBABA_CLOUD_ACCESS_KEY_ID 和 ALIBABA_CLOUD_ACCESS_KEY_SECRET。
        // 工程代码泄露可能会导致 AccessKey 泄露，并威胁账号下所有资源的安全性。以下代码示例使用环境变量获取 AccessKey 的方式进行调用，仅供参考，建议使用更安全的 STS 方式，更多鉴权访问方式请参见：https://help.aliyun.com/document_detail/378657.html
        com.aliyun.resourcesharing20200110.Client client = createClient(
            System.getenv("ALIBABA_CLOUD_ACCESS_KEY_ID"), System.getenv("ALIBABA_CLOUD_ACCESS_KEY_SECRET"));
        try {
            // 查询共享邀请列表
            com.aliyun.resourcesharing20200110.models.ListResourceShareInvitationsRequest
                listResourceShareInvitationsRequest
                = new com.aliyun.resourcesharing20200110.models.ListResourceShareInvitationsRequest();
            com.aliyun.teautil.models.RuntimeOptions runtime = new com.aliyun.teautil.models.RuntimeOptions();
            // 复制代码运行请自行打印 API 的返回值
            ListResourceShareInvitationsResponse listResourceShareInvitationsResponse
                = client.listResourceShareInvitationsWithOptions(listResourceShareInvitationsRequest, runtime);
            com.aliyun.teaconsole.Client.log(
                com.aliyun.teautil.Common.toJSONString(listResourceShareInvitationsResponse));
            List<ListResourceShareInvitationsResponseBodyResourceShareInvitations> resourceShareInvitations
                = listResourceShareInvitationsResponse.getBody().getResourceShareInvitations();

            for (ListResourceShareInvitationsResponseBodyResourceShareInvitations resourceShareInvitation :
                resourceShareInvitations) {
                //接收共享邀请
                AcceptResourceShareInvitationRequest acceptResourceShareInvitationRequest
                    = new AcceptResourceShareInvitationRequest();
                acceptResourceShareInvitationRequest.setResourceShareInvitationId(
                    resourceShareInvitation.getResourceShareInvitationId());
                AcceptResourceShareInvitationResponse acceptResourceShareInvitationResponse
                    = client.acceptResourceShareInvitation(acceptResourceShareInvitationRequest);
                com.aliyun.teaconsole.Client.log(
                    com.aliyun.teautil.Common.toJSONString(acceptResourceShareInvitationResponse));

                //拒绝共享邀请
                //RejectResourceShareInvitationRequest rejectResourceShareInvitationRequest
                //    = new RejectResourceShareInvitationRequest();
                //rejectResourceShareInvitationRequest.setResourceShareInvitationId(
                //    resourceShareInvitation.getResourceShareInvitationId());
                //RejectResourceShareInvitationResponse rejectResourceShareInvitationResponse
                //    = client.rejectResourceShareInvitation(rejectResourceShareInvitationRequest);
                //com.aliyun.teaconsole.Client.log(
                //    com.aliyun.teautil.Common.toJSONString(rejectResourceShareInvitationResponse));
            }
        } catch (TeaException error) {
            // 如有需要，请打印 error
            com.aliyun.teautil.Common.assertAsString(error.message);
        } catch (Exception _error) {
            TeaException error = new TeaException(_error.getMessage(), _error);
            // 如有需要，请打印 error
            com.aliyun.teautil.Common.assertAsString(error.message);
        }
    }
}
