package com.aliyun.sample;

import java.util.Arrays;
import java.util.concurrent.CompletableFuture;

import com.aliyun.auth.credentials.Credential;
import com.aliyun.auth.credentials.provider.StaticCredentialProvider;
import com.aliyun.sdk.service.ecs20140526.AsyncClient;
import com.aliyun.sdk.service.ecs20140526.models.CreateDiskRequest;
import com.aliyun.sdk.service.ecs20140526.models.CreateDiskResponse;
import com.aliyun.sdk.service.ecs20140526.models.DescribeSnapshotsRequest;
import com.aliyun.sdk.service.ecs20140526.models.DescribeSnapshotsResponse;
import com.aliyun.tea.TeaException;
import darabonba.core.client.ClientOverrideConfiguration;

/**
 * 本用例演示了如何使用共享的快照资源来创建一块数据盘
 * ECS创建磁盘API参考文档：https://help.aliyun.com/zh/ecs/developer-reference/api-createdisk
 * 开发者门户：https://next.api.aliyun.com/api/Ecs/2014-05-26/CreateDisk
 * 相关实例内容仅供参考，请根据实际情况修改
 **/
public class UseResourceShare {
    private static final String SNAPSHOT_SHARE_FROM_TAG = "acs:ecs:sharedFrom";

    private static final Long SNAPSHOT_SHARE_From_UID = 0L;
    private static final String SNAPSHOT_SHARE_From_REGION = "";
    private static final String SNAPSHOT_SHARE_From_SNAPSHOT = "";

    /**
     * 使用AK&SK初始化账号Client
     *
     * @param accessKeyId
     * @param accessKeySecret
     * @return Client
     * @throws Exception
     */
    public static AsyncClient createClient(String accessKeyId, String accessKeySecret)
        throws Exception {
        // HttpClient Configuration
        /*HttpClient httpClient = new ApacheAsyncHttpClientBuilder()
                .connectionTimeout(Duration.ofSeconds(10)) // Set the connection timeout time, the default is 10 seconds
                .responseTimeout(Duration.ofSeconds(10)) // Set the response timeout time, the default is 20 seconds
                .maxConnections(128) // Set the connection pool size
                .maxIdleTimeOut(Duration.ofSeconds(50)) // Set the connection pool timeout, the default is 30 seconds
                // Configure the proxy
                .proxy(new ProxyOptions(ProxyOptions.Type.HTTP, new InetSocketAddress("<your-proxy-hostname>", 9001))
                        .setCredentials("<your-proxy-username>", "<your-proxy-password>"))
                // If it is an https connection, you need to configure the certificate, or ignore the certificate(
                .ignoreSSL(true))
                .x509TrustManagers(new X509TrustManager[]{})
                .keyManagers(new KeyManager[]{})
                .ignoreSSL(false)
                .build();*/

        // Configure Credentials authentication information, including ak, secret, token
        StaticCredentialProvider provider = StaticCredentialProvider.create(Credential.builder()
            // Please ensure that the environment variables ALIBABA_CLOUD_ACCESS_KEY_ID and
            // ALIBABA_CLOUD_ACCESS_KEY_SECRET are set.
            .accessKeyId(accessKeyId).accessKeySecret(accessKeySecret)
            //.securityToken(System.getenv("ALIBABA_CLOUD_SECURITY_TOKEN")) // use STS token
            .build());

        // Configure the Client
        return AsyncClient.builder()
            .region("cn-hangzhou") // Region ID
            //.httpClient(httpClient) // Use the configured HttpClient, otherwise use the default HttpClient (Apache
            // HttpClient)
            .credentialsProvider(provider)
            //.serviceConfiguration(Configuration.create()) // Service-level configuration
            // Client-level configuration rewrite, can set Endpoint, Http request parameters, etc.
            .overrideConfiguration(
                ClientOverrideConfiguration.create()
                    // Endpoint 请参考 https://api.aliyun.com/product/Ecs
                    .setEndpointOverride("ecs.cn-hangzhou.aliyuncs.com")
                //.setConnectTimeout(Duration.ofSeconds(30))
            ).build();
    }

    /**
     * 构建共享快照的标识
     * @param fromUid
     * @param regionId
     * @param snapshotId
     * @return
     */
    private static String buildShareFrom(Long fromUid, String regionId, String snapshotId) {
        return fromUid + ":" + regionId + ":" + snapshotId;
    }

    public static void main(String[] args_) throws Exception {
        // 请确保代码运行环境设置了环境变量 ALIBABA_CLOUD_ACCESS_KEY_ID 和 ALIBABA_CLOUD_ACCESS_KEY_SECRET。
        // 工程代码泄露可能会导致 AccessKey 泄露，并威胁账号下所有资源的安全性。以下代码示例使用环境变量获取 AccessKey 的方式进行调用，仅供参考，建议使用更安全的 STS 方式，更多鉴权访问方式请参见：https://help.aliyun.com/document_detail/378657.html
        AsyncClient client = createClient(System.getenv("ALIBABA_CLOUD_ACCESS_KEY_ID"), System.getenv("ALIBABA_CLOUD_ACCESS_KEY_SECRET"));
        try {
            //查看共享给自己的快照列表

            //如果能明确知道共享的来源，可以精确查询。不知道共享源信息，只能按照快照类型来查询
            DescribeSnapshotsRequest.Tag shareFromTag = DescribeSnapshotsRequest.Tag.builder()
                .key(SNAPSHOT_SHARE_FROM_TAG)
                .value(buildShareFrom(SNAPSHOT_SHARE_From_UID, SNAPSHOT_SHARE_From_REGION, SNAPSHOT_SHARE_From_SNAPSHOT))
                .build();

            //查询杭州地域下的共享快照
            DescribeSnapshotsRequest describeSnapshotsRequest = DescribeSnapshotsRequest.builder().regionId(
                    "$要查询资源的地域$").snapshotType("shared")
                .tag(Arrays.asList(shareFromTag))
                .build();

            CompletableFuture<DescribeSnapshotsResponse> describeSnapshotsResponse = client.describeSnapshots(
                describeSnapshotsRequest);
            DescribeSnapshotsResponse describeSnapshots = describeSnapshotsResponse.get();
            com.aliyun.teaconsole.Client.log(com.aliyun.teautil.Common.toJSONString(describeSnapshots));
            if (describeSnapshots.getBody().getSnapshots().getSnapshot().size() == 0) {
                System.out.println("没有共享快照");
                return;
            }
            //用例使用的共享快照，实际使用时请根据实际情况修改
            String snapshotId = describeSnapshots.getBody().getSnapshots().getSnapshot().get(0).getSnapshotId();
            //使用共享的快照创建磁盘
            CreateDiskRequest createDiskRequest = CreateDiskRequest.builder().regionId("$创建磁盘的地域$").snapshotId(
                snapshotId).zoneId("$制定磁盘可用区$").diskCategory("$制定磁盘类型$")
                //.size($磁盘大小$)
                .build();
            // 复制代码运行请自行打印 API 的返回值
            CompletableFuture<CreateDiskResponse> createDiskResponse = client.createDisk(createDiskRequest);
            com.aliyun.teaconsole.Client.log(
                com.aliyun.teautil.Common.toJSONString(createDiskResponse.get().getBody().getDiskId()));
        } catch (TeaException error) {
            // 如有需要，请打印 error
            com.aliyun.teautil.Common.assertAsString(error.message);
        } catch (Exception _error) {
            TeaException error = new TeaException(_error.getMessage(), _error);
            // 如有需要，请打印 error
            com.aliyun.teaconsole.Client.log(com.aliyun.teautil.Common.toJSONString(error));
        }
    }
}
